@@ -7,7 +7,7 @@
         <location filename="../src/policykitagent.cpp" line="85"/>
         <location filename="../src/policykitagent.cpp" line="183"/>
         <source>PolicyKit Information</source>
-        <translation>Informações PolicyKit</translation>
+        <translation>Informações do PolicyKit</translation>
     </message>
     <message>
         <location filename="../src/policykitagent.cpp" line="82"/>
@@ -46,7 +46,7 @@
         <location filename="../src/policykitagentgui.ui" line="65"/>
         <location filename="../src/policykitagentgui.cpp" line="74"/>
         <source>Password:</source>
-        <translation>Palavra-passe:</translation>
+        <translation>Senha:</translation>
     </message>
 </context>
 </TS>
